"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prettier_config_1 = tslib_1.__importDefault(require("@namics/prettier-config"));
const prettier_1 = require("prettier");
const chunk_1 = require("../chunk");
const template_1 = tslib_1.__importDefault(require("./template"));
exports.pluginNameMap = {
    PluginTerminal: 'PluginTerminal',
    PluginNpmScripts: 'PluginNpmScripts',
    PluginReadme: 'PluginReadme',
    PluginCodeCoverage: 'PluginCodeCoverage',
};
const pluginMap = {
    PluginTerminal: {
        url: () => `https://github.com/smollweide/dash4/tree/master/plugins/plugin-terminal`,
        import: () => `const { PluginTerminal } = require('@dash4/plugin-terminal');`,
        content: (options) => `<DASH4>new PluginTerminal(${JSON.stringify(options)})</DASH4>`,
    },
    PluginNpmScripts: {
        url: () => `https://github.com/smollweide/dash4/tree/master/plugins/plugin-npm-scripts`,
        import: () => `const { PluginNpmScripts } = require('@dash4/plugin-npm-scripts');`,
        content: (options) => `<DASH4>new PluginNpmScripts(${JSON.stringify(options)})</DASH4>`,
    },
    PluginReadme: {
        url: () => `https://github.com/smollweide/dash4/tree/master/plugins/plugin-readme`,
        import: () => `const { PluginReadme } = require('@dash4/plugin-readme');`,
        content: (options) => `<DASH4>new PluginReadme(${JSON.stringify(options)})</DASH4>`,
    },
    PluginCodeCoverage: {
        url: () => `https://github.com/smollweide/dash4/tree/master/plugins/plugin-code-coverage`,
        import: () => `const { PluginCodeCoverage } = require('@dash4/plugin-code-coverage');`,
        content: (options) => `<DASH4>new PluginCodeCoverage(${options ? JSON.stringify(options) : ''})</DASH4>`,
    },
};
class Config {
    constructor({ port }) {
        this._imports = {};
        this._tabs = {};
        this.addPlugin = (tabName, name, options) => {
            this._imports[name] = `// ${pluginMap[name].url()}\n${pluginMap[name].import()}`;
            if (!this._tabs[tabName]) {
                this._tabs[tabName] = [];
            }
            this._tabs[tabName].push(pluginMap[name].content(options));
        };
        this._port = port;
    }
    get tabs() {
        const tabs = [];
        Object.keys(this._tabs).forEach((tabName) => {
            tabs.push({
                title: tabName,
                rows: chunk_1.chunk(this._tabs[tabName], 2),
            });
        });
        return tabs;
    }
    get tabsString() {
        return JSON.stringify(this.tabs, null, 2)
            .replace(/"<DASH4>/g, '')
            .replace(/<\/DASH4>"/g, '')
            .replace(/\\"/g, '"');
    }
    get imports() {
        return Object.keys(this._imports)
            .map((key) => this._imports[key])
            .join(`\n`);
    }
    toString() {
        return prettier_1.format(template_1.default({
            imports: this.imports,
            port: this._port,
            tabs: this.tabsString,
        }), prettier_config_1.default);
    }
}
exports.Config = Config;
//# sourceMappingURL=Config.js.map