"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/// <reference types="@types/jest" />
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const Config_1 = require("./Config");
describe('Config', () => {
    test('is function', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect(typeof Config_1.Config).toBe('function');
    }));
    test('add plugin', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const config = new Config_1.Config({ port: 8080 });
        config.addPlugin('Root', 'PluginCodeCoverage');
        expect(config.tabs).toEqual([
            {
                title: 'Root',
                rows: [['<DASH4>new PluginCodeCoverage()</DASH4>']],
            },
        ]);
        expect(config.imports).toBe(`// https://github.com/smollweide/dash4/tree/master/plugins/plugin-code-coverage\nconst { PluginCodeCoverage } = require('@dash4/plugin-code-coverage');`);
    }));
    test('add multiple plugins', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const config = new Config_1.Config({ port: 8080 });
        config.addPlugin('Root', 'PluginTerminal', { cmd: 'npm run test' });
        config.addPlugin('Root', 'PluginCodeCoverage');
        config.addPlugin('Root', 'PluginReadme', { file: 'README.md' });
        config.addPlugin('Root', 'PluginNpmScripts', {
            scripts: [
                {
                    title: 'build',
                    cmd: 'npm run build',
                },
            ],
        });
        expect(config.tabs).toEqual([
            {
                title: 'Root',
                rows: [
                    [
                        '<DASH4>new PluginTerminal({"cmd":"npm run test"})</DASH4>',
                        '<DASH4>new PluginCodeCoverage()</DASH4>',
                    ],
                    [
                        '<DASH4>new PluginReadme({"file":"README.md"})</DASH4>',
                        '<DASH4>new PluginNpmScripts({"scripts":[{"title":"build","cmd":"npm run build"}]})</DASH4>',
                    ],
                ],
            },
        ]);
        expect(config.imports).toBe([
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-terminal`,
            `const { PluginTerminal } = require('@dash4/plugin-terminal');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-code-coverage`,
            `const { PluginCodeCoverage } = require('@dash4/plugin-code-coverage');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-readme`,
            `const { PluginReadme } = require('@dash4/plugin-readme');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-npm-scripts`,
            `const { PluginNpmScripts } = require('@dash4/plugin-npm-scripts');`,
        ].join('\n'));
        // await fs.writeFile('src/t.js', inst.config);
        expect(config.toString()).toBe(yield fs_extra_1.default.readFile(path_1.default.join(process.cwd(), 'src/__mocks__/config/_dash4.config.js'), 'utf8'));
    }));
    test('add plugins in mutiple tabs', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const config = new Config_1.Config({ port: 8080 });
        config.addPlugin('Root', 'PluginTerminal', { cmd: 'npm run test' });
        config.addPlugin('Cli', 'PluginCodeCoverage');
        config.addPlugin('Client', 'PluginReadme', { file: 'README.md' });
        config.addPlugin('Client', 'PluginNpmScripts', {
            scripts: [
                {
                    title: 'build',
                    cmd: 'npm run build',
                },
            ],
        });
        expect(config.tabs).toEqual([
            {
                title: 'Root',
                rows: [['<DASH4>new PluginTerminal({"cmd":"npm run test"})</DASH4>']],
            },
            {
                title: 'Cli',
                rows: [['<DASH4>new PluginCodeCoverage()</DASH4>']],
            },
            {
                title: 'Client',
                rows: [
                    [
                        '<DASH4>new PluginReadme({"file":"README.md"})</DASH4>',
                        '<DASH4>new PluginNpmScripts({"scripts":[{"title":"build","cmd":"npm run build"}]})</DASH4>',
                    ],
                ],
            },
        ]);
        expect(config.imports).toBe([
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-terminal`,
            `const { PluginTerminal } = require('@dash4/plugin-terminal');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-code-coverage`,
            `const { PluginCodeCoverage } = require('@dash4/plugin-code-coverage');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-readme`,
            `const { PluginReadme } = require('@dash4/plugin-readme');`,
            `// https://github.com/smollweide/dash4/tree/master/plugins/plugin-npm-scripts`,
            `const { PluginNpmScripts } = require('@dash4/plugin-npm-scripts');`,
        ].join('\n'));
        expect(config.toString()).toBe(yield fs_extra_1.default.readFile(path_1.default.join(process.cwd(), 'src/__mocks__/config/_lerna-dash4.config.js'), 'utf8'));
    }));
});
//# sourceMappingURL=Config.spec.js.map